//
// Private header file for the Printer Application Framework
//
// Copyright © 2019-2022 by Michael R Sweet.
//
// Licensed under Apache License v2.0.  See the file "LICENSE" for more
// information.
//

#ifndef _PAPPL_PAPPL_PRIVATE_H_
#  define _PAPPL_PAPPL_PRIVATE_H_
#  include "client-private.h"
#  include "device.h"
#  include "dnssd-private.h"
#  include "job-private.h"
#  include "loc-private.h"
#  include "log-private.h"
#  include "mainloop-private.h"
#  include "printer-private.h"
#  include "system-private.h"
#endif // !_PAPPL_PAPPL_PRIVATE_H_
